<?php
/**
 * @file
 * Drush integration functions for the PIFT module.
 */

/**
 * Implements hook_drush_command().
 */
function pift_drush_command() {
  $items = array();

  $items['pift-cron'] = array(
    'description' => 'Send batch for testing, and retrieve results.',
  );

  $items['pift-cron-retest'] = array(
    'description' => 'Requeue expired test results.',
    'arguments' => array(
      'quantity' => 'Maximum number of tests to requeue. (Defaults to "3").',
    ),
    'options' => array(
      'project' => array(
        'description' => 'Comma delimited list of project ids to include.',
        'value' => 'required',
      ),
      'count' => 'Return the number of tests meeting the retest criteria, without queuing tests.',
    ),
  );

  return $items;
}

/**
 * Send batch for testing, and retrieve results.
 */
function drush_pift_cron() {
  module_load_include('cron.inc', 'pift');

  // Check whether retesting is enabled
  if (PIFT_RETEST_FREQUENCY != -1) {
    // Requeue all tests that have passed the re-test interval.
    pift_cron_retest();
  }

  // Send a batch of queued tests.
  pift_cron_queue_batch();

  // Retrieve any results that have occured since last cron run.
  pift_cron_retrieve_results();
}

/**
 * Requeue expired test results
 */
function drush_pift_cron_retest($quantity = 3) {
  module_load_include('cron.inc', 'pift');

  // Requeue all tests that have passed the re-test interval
  $projects = array();

  $count_only_flag = drush_get_option('count');

  if ($projects = drush_get_option('project')) {
    pift_cron_retest($quantity, $count_only_flag, explode(',', $projects));
  }
  else {
    pift_cron_retest($quantity, $count_only_flag);
  }
}