<?php

/**
 * @file
 * Provides nodechanges integration for the PIFT module.
 */

/**
 * Implements hook_nodechanges_file_changes_element_alter().
 *
 * Adds test status and results to the extended_file_field formatter output on
 * nodechanges file changes fields.
 */
function pift_nodechanges_file_changes_element_alter(&$element, $context) {
  $retest = user_access('pift re-test files');
  $fids = array_keys($element['#files']);

  // If there are no files, bail.
  if (empty($fids)) {
    return;
  }

  $node = $context['entity'];
  $new_rows = array();

  // Loop through each file row, adding the test results as necessary.
  foreach ($element['#rows'] as $fid => $row) {

    // Generate our replacement row items, maintaining any existing classes,
    // attributes, etc.
    if (!isset($row['data'])) {
      $new_rows[$fid] = array('data' => $row, 'class' => array('pift-file-info'));
    }
    else {
      $new_rows[$fid] = $row;
      $new_rows[$fid]['class'][] = 'pift-file-info';
    }

    // Add PIFT Test results
    if (!empty($node->test_results[$fid])) {
      $file = (array) $element['#files'][$fid];
      $file['pift_id'] = $node->test_results[$fid]['test_id'];
      $file['pift_status'] = $node->test_results[$fid]['status'];
      $file['pift_message'] = $node->test_results[$fid]['message'];
      $file['pift_operations'] = array('view' => $node->test_results[$fid]['test_id']);
      $classes = array('', 'pift-queue', 'pift-retest', 'pift-fail', 'pift-pass');
      if ($retest && in_array($node->test_results[$fid]['status'], array(PIFT_STATUS_FAIL, PIFT_STATUS_PASS)) && $file['file_status'] != 'deleted') {
        $file['pift_operations']['retest'] = $node->test_results[$fid]['test_id'];
      }

      // Add a rowspan and css class to the first cell of the existing row.
      if (!is_array($new_rows[$fid]['data'][0])) {
        $new_rows[$fid]['data'][0] = array('data' => $new_rows[$fid]['data'][0], 'class' => array());
      }
      $new_rows[$fid]['data'][0]['class'] = !empty($new_rows[$fid]['data'][0]['class']) ? array_unique(array_merge($new_rows[$fid]['data'][0]['class'], array('pift-file-status'))) : array('pift-file-status');
      $new_rows[$fid]['data'][0]['rowspan'] = !empty($new_rows[$fid]['data'][0]['rowspan']) ? $new_rows[$fid]['data'][0]['rowspan']++ : 2;

      // Add the test status as a class to the existing row.
      $new_rows[$fid]['class'][] = $classes[$file['pift_status']];

      // Generate the results row
      $message = pift_extended_file_field_message_formatter($file, array());
      $operations = pift_extended_file_field_operations_formatter($file, array());
      if (!empty($operations)) {
        $message .= '<div class="pift-operations">[ ' . $operations . ' ]</div>';
      }
      $new_rows["$fid-results"] = array(
        'data' => array(
          array(
            'data' => $message,
            'class' => array($classes[$file['pift_status']]),
            'colspan' => 2,
          ),
        ),
        'class' => array('pift-test-info'),
      );
    }
  }

  // Replace our table rows with the updated element.
  $element['#rows'] = $new_rows;
}
